==> widgetbook-0.0.1.tar.gz: lib/src/widgets/device_item.dart <==
import 'package:flutter/material.dart';
import 'package:widgetbook/src/cubit/device/device_cubit.dart';
import 'package:widgetbook/src/models/device.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:flutter_bloc/flutter_bloc.dart';
import '../utils/extensions.dart';

class DeviceItem extends StatelessWidget {
  final Device device;
  const DeviceItem({
    Key? key,
    required this.device,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return BlocBuilder<DeviceCubit, DeviceState>(
      builder: (context, state) {
        bool isCurrent = device == state.currentDevice;
        return GestureDetector(
          onTap: () {
            context.read<DeviceCubit>().selectDevice(
                  device,
                );
          },
          child: buildTooltip(
            context: context,
            isCurrent: isCurrent,
          ),
        );
      },
    );
  }

  Widget buildTooltip(
      {required BuildContext context, required bool isCurrent}) {
    return Tooltip(
      child: buildIcon(
        device.type,
        isCurrent ? context.colorScheme.primary : context.theme.hintColor,
      ),
      message: device.name,
    );
  }

  Widget buildIcon(DeviceType type, Color color) {
    switch (type) {
      case DeviceType.watch:
        return Icon(
          FontAwesomeIcons.clock,
          color: color,
        );
      case DeviceType.mobile:
        return Icon(
          FontAwesomeIcons.mobile,
          color: color,
        );
      case DeviceType.tablet:
        return Icon(
          FontAwesomeIcons.tablet,
          color: color,
        );
      case DeviceType.desktop:
        return Icon(
          FontAwesomeIcons.desktop,
          color: color,
        );
      case DeviceType.unknown:
        return Icon(
          FontAwesomeIcons.question,
          color: color,
        );
    }
  }
}

==> widgetbook-0.0.10.tar.gz: lib/src/widgets/device_item.dart <==
import 'package:flutter/material.dart';
import 'package:widgetbook/src/models/device.dart';
import 'package:widgetbook/src/providers/device_provider.dart';
import 'package:widgetbook/src/utils/extensions.dart';

class DeviceItem extends StatelessWidget {
  const DeviceItem({
    Key? key,
    required this.device,
  }) : super(key: key);

  final Device device;

  @override
  Widget build(BuildContext context) {
    final deviceProvider = DeviceProvider.of(context)!;
    final state = deviceProvider.state;
    final isCurrent = device == state.currentDevice;

    return GestureDetector(
      onTap: () {
        deviceProvider.selectDevice(
          device,
        );
      },
      child: buildTooltip(
        context: context,
        isCurrent: isCurrent,
      ),
    );
  }

  Widget buildTooltip(
      {required BuildContext context, required bool isCurrent}) {
    return Tooltip(
      message: device.name,
      child: buildIcon(
        device.type,
        isCurrent ? context.colorScheme.primary : context.theme.hintColor,
      ),
    );
  }

  Widget buildIcon(DeviceType type, Color color) {
    switch (type) {
      case DeviceType.watch:
        return Icon(
          Icons.watch,
          color: color,
        );
      case DeviceType.mobile:
        return Icon(
          Icons.smartphone,
          color: color,
        );
      case DeviceType.tablet:
        return Icon(
          Icons.tablet,
          color: color,
        );
      case DeviceType.desktop:
        return Icon(
          Icons.desktop_windows,
          color: color,
        );
      case DeviceType.unknown:
        return Icon(
          Icons.quiz,
          color: color,
        );
    }
  }
}
